@@ -5,7 +5,7 @@
 /*                                                                           */
 /* Copyright (C) 2011-2013 Discrete Optimization, TU Darmstadt,              */
 /*                         EDOM, FAU Erlangen-Nürnberg                       */
-/*               2014-2024 Discrete Optimization, TU Darmstadt               */
+/*               2014-2025 Discrete Optimization, TU Darmstadt               */
 /*                                                                           */
 /*                                                                           */
 /* Licensed under the Apache License, Version 2.0 (the "License");           */
@@ -22,7 +22,7 @@
 /*                                                                           */
 /*                                                                           */
 /* Based on SCIP - Solving Constraint Integer Programs                       */
-/* Copyright (C) 2002-2024 Zuse Institute Berlin                             */
+/* Copyright (C) 2002-2025 Zuse Institute Berlin                             */
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -273,10 +273,17 @@ SCIP_RETCODE SCIPincludeTableRelaxSdp(
    SCIP_CALL( SCIPallocMemory(scip, &tabledata) );
 
    /* include statistics table */
+#if SCIP_VERSION_MAJOR >= 10
+   SCIP_CALL( SCIPincludeTable(scip, TABLE_NAME, TABLE_DESC, TABLE_ACTIVE,
+         tableCopyRelaxSdp, tableFreeRelaxSdp, NULL, NULL,
+         tableInitsolRelaxSdp, NULL, tableOutputRelaxSdp, NULL,
+         tabledata, TABLE_POSITION, TABLE_EARLIEST_STAGE) );
+#else
    SCIP_CALL( SCIPincludeTable(scip, TABLE_NAME, TABLE_DESC, TABLE_ACTIVE,
          tableCopyRelaxSdp, tableFreeRelaxSdp, NULL, NULL,
          tableInitsolRelaxSdp, NULL, tableOutputRelaxSdp,
          tabledata, TABLE_POSITION, TABLE_EARLIEST_STAGE) );
+#endif
 
    /* add "absolute" parameter */
    SCIP_CALL( SCIPaddBoolParam( scip, "table/relaxsdp/absolute", "Should statistics be printed in absolute numbers (true) or percentages (false)?",
