@@ -5,7 +5,7 @@
 /*                                                                           */
 /* Copyright (C) 2011-2013 Discrete Optimization, TU Darmstadt,              */
 /*                         EDOM, FAU Erlangen-Nürnberg                       */
-/*               2014-2024 Discrete Optimization, TU Darmstadt               */
+/*               2014-2025 Discrete Optimization, TU Darmstadt               */
 /*                                                                           */
 /*                                                                           */
 /* Licensed under the Apache License, Version 2.0 (the "License");           */
@@ -22,7 +22,7 @@
 /*                                                                           */
 /*                                                                           */
 /* Based on SCIP - Solving Constraint Integer Programs                       */
-/* Copyright (C) 2002-2024 Zuse Institute Berlin                             */
+/* Copyright (C) 2002-2025 Zuse Institute Berlin                             */
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -531,3 +531,84 @@ SCIP_RETCODE SCIPsolveOneVarSDPDense(
 
    return SCIP_OKAY;
 }
+
+/** estimates curvature by taking one Newton step */
+SCIP_RETCODE SCIPestimOneVarCurvatureDense(
+   BMS_BUFMEM*           bufmem,             /**< buffer memory */
+   SCIP_Real             lb,                 /**< lower bound of variable */
+   int                   blocksize,          /**< size of the SDP-block */
+   SCIP_Real*            fullconstmatrix,    /**< dense full constant matrix */
+   int                   sdpnnonz,           /**< number of nonzero elements in the SDP-constraint-matrix */
+   int*                  sdprow,             /**< array of row-indices of nonzero matrix entries */
+   int*                  sdpcol,             /**< array of column-indices of nonzero matrix entries */
+   SCIP_Real*            sdpval,             /**< array of nonzero values */
+   SCIP_Real             infinity,           /**< infinity value */
+   SCIP_Real*            curvature           /**< pointer to store curvature (or NULL) */
+   )
+{
+   SCIP_Real* fullmatrix;
+   SCIP_Real* tmpmatrix;
+   SCIP_Real* eigenvector = NULL;
+   SCIP_Real firsteigenvalue;
+   SCIP_Real secondeigenvalue;
+   SCIP_Real supergradient = SCIP_INVALID;
+   SCIP_Real mu;
+   int r;
+   int c;
+   int i;
+
+   assert( fullconstmatrix != NULL );
+   assert( sdpnnonz == 0 || sdprow != NULL );
+   assert( sdpnnonz == 0 || sdpcol != NULL );
+   assert( sdpnnonz == 0 || sdpval != NULL );
+   assert( curvature != NULL );
+
+   *curvature = SCIP_INVALID;
+
+   /* can currently only treat the case with finite lower and upper bounds */
+   if ( lb <= -infinity )
+      return SCIP_OKAY;
+
+   /* fill in full matrices */
+   BMS_CALL( BMSallocClearBufferMemoryArray(bufmem, &fullmatrix, blocksize * blocksize) );
+   BMS_CALL( BMSallocClearBufferMemoryArray(bufmem, &tmpmatrix, blocksize * blocksize) );
+   BMS_CALL( BMSallocBufferMemoryArray(bufmem, &eigenvector, blocksize) );
+
+   for (i = 0; i < sdpnnonz; ++i)
+   {
+      r = sdprow[i];
+      c = sdpcol[i];
+      assert( fullmatrix[r * blocksize + c] == 0.0 );
+      assert( fullmatrix[c * blocksize + r] == 0.0 );
+      fullmatrix[r * blocksize + c] = sdpval[i];
+      fullmatrix[c * blocksize + r] = sdpval[i];
+   }
+
+   /* compute linear combination at lb */
+   mu = lb;
+   for (i = 0; i < blocksize * blocksize; ++i)
+      tmpmatrix[i] = mu * fullmatrix[i] - fullconstmatrix[i];
+
+   /* compute eigenvector at lower bound */
+   SCIP_CALL( SCIPlapackComputeIthEigenvalue(bufmem, TRUE, blocksize, tmpmatrix, 1, &firsteigenvalue, eigenvector) );
+
+   /* compute supergradient value */
+   computeSupergradient(sdpnnonz, sdprow, sdpcol, sdpval, eigenvector, &supergradient);
+
+   /* take an arbitrary step */
+   mu =+ 1.0;
+   for (i = 0; i < blocksize * blocksize; ++i)
+      tmpmatrix[i] = mu * fullmatrix[i] - fullconstmatrix[i];
+
+   /* compute eigenvector at lower bound */
+   SCIP_CALL( SCIPlapackComputeIthEigenvalue(bufmem, FALSE, blocksize, tmpmatrix, 1, &secondeigenvalue, NULL) );
+
+   /* alternative: REALABS(firsteigenvalue + supergradient) / MAX(1e-6, REALABS(secondeigenvalue)) */
+   *curvature = REALABS(firsteigenvalue + supergradient - secondeigenvalue);
+
+   BMSfreeBufferMemoryArray(bufmem, &eigenvector);
+   BMSfreeBufferMemoryArray(bufmem, &tmpmatrix);
+   BMSfreeBufferMemoryArray(bufmem, &fullmatrix);
+
+   return SCIP_OKAY;
+}
