@@ -5,7 +5,7 @@
 /*                                                                           */
 /* Copyright (C) 2011-2013 Discrete Optimization, TU Darmstadt,              */
 /*                         EDOM, FAU Erlangen-Nürnberg                       */
-/*               2014-2024 Discrete Optimization, TU Darmstadt               */
+/*               2014-2025 Discrete Optimization, TU Darmstadt               */
 /*                                                                           */
 /*                                                                           */
 /* Licensed under the Apache License, Version 2.0 (the "License");           */
@@ -22,7 +22,7 @@
 /*                                                                           */
 /*                                                                           */
 /* Based on SCIP - Solving Constraint Integer Programs                       */
-/* Copyright (C) 2002-2024 Zuse Institute Berlin                             */
+/* Copyright (C) 2002-2025 Zuse Institute Berlin                             */
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -87,6 +87,20 @@ SCIP_RETCODE SCIPsolveOneVarSDPDense(
    SCIP_Real*            optval              /**< pointer to store optimal value of variable */
    );
 
+/** estimates curvature by taking one Newton step */
+SCIP_RETCODE SCIPestimOneVarCurvatureDense(
+   BMS_BUFMEM*           bufmem,             /**< buffer memory */
+   SCIP_Real             lb,                 /**< lower bound of variable */
+   int                   blocksize,          /**< size of the SDP-block */
+   SCIP_Real*            fullconstmatrix,    /**< dense full constant matrix */
+   int                   sdpnnonz,           /**< number of nonzero elements in the SDP-constraint-matrix */
+   int*                  sdprow,             /**< array of row-indices of nonzero matrix entries */
+   int*                  sdpcol,             /**< array of column-indices of nonzero matrix entries */
+   SCIP_Real*            sdpval,             /**< array of nonzero values */
+   SCIP_Real             infinity,           /**< infinity value */
+   SCIP_Real*            curvature           /**< pointer to store curvature (or NULL) */
+   );
+
 #ifdef __cplusplus
 }
 #endif
